@@ -663,11 +663,11 @@ mapset_changed_cb (GConfClient *client,
 		g_free (mapset_tmp);
 	
 	dialog = gtk_message_dialog_new (
-		NULL,
+		GTK_WINDOW (window),
 		GTK_DIALOG_MODAL,
 		GTK_MESSAGE_INFO,
 		GTK_BUTTONS_CLOSE,
-		_("This new mapset will take effect when you start up"
+		_("This new mapset will take effect when you start "
 		  "a new game, or when Mahjongg is restarted."));
 
 	gtk_dialog_run (GTK_DIALOG (dialog));
@@ -680,7 +680,7 @@ set_map_selection (GtkWidget *widget, void *data)
 	struct _maps *map = (struct _maps*) data;
 
 	g_free (mapset);
-	mapset = map->name;
+	mapset = g_strdup (map->name);
 
 	gconf_client_set_string (conf_client,
 				 "/apps/mahjongg/mapset",
@@ -909,7 +909,7 @@ fill_tile_menu (GtkWidget *menu, gchar *sdir, gint is_tile)
         gint itemno = 0;
 	gchar *dname = NULL;
 
-	dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
+	dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
 			(sdir), FALSE, NULL);
 	dir = opendir (dname);
 
@@ -1345,7 +1345,7 @@ about_callback (GtkWidget *widget, gpointer data)
 		char *filename = NULL;
 
 		filename = gnome_program_locate_file (NULL,
-				GNOME_FILE_DOMAIN_PIXMAP, 
+				GNOME_FILE_DOMAIN_APP_PIXMAP, 
 				"gnome-mahjongg.png",
 				TRUE, NULL);
 		if (filename != NULL) {
@@ -1365,7 +1365,7 @@ about_callback (GtkWidget *widget, gpointer data)
 				 (const gchar **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
-
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
 	gtk_widget_show (about);
 }
 
@@ -1755,12 +1755,12 @@ load_tiles (gchar *fname, gchar *bg_fname)
 
 	tmp = g_strconcat ("mahjongg/", fname, NULL);
 	
-	fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, (tmp), FALSE, NULL);
+	fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
 	g_free (tmp);
 
 	tmp = g_strconcat ("mahjongg/bg/", bg_fname, NULL);
 
-	bg_fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, (tmp), FALSE, NULL);
+	bg_fn = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, (tmp), FALSE, NULL);
 	g_free (tmp);
 
 	if (!g_file_test ((fn), G_FILE_TEST_EXISTS)) {
@@ -1908,7 +1908,7 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
 
         do {
                 num_shuffle++;
-                /* We do a circular permutation (FIXME: check the english term...)*/
+                /* We do a circular permutation */
                 for (i=0; i<MAX_TILES; i++) {
                         if (tiles[i].visible) {
                                 if (first) {
@@ -1936,6 +1936,7 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
 					     GTK_BUTTONS_OK,
 					     (_("Sorry, I was unable to find a playable configuration.")));
 		gtk_dialog_run (GTK_DIALOG (mb));
+		gtk_widget_destroy (mb);
 
         } else {
                 
